import os
import sys
from shpimporter import DEBUG, INFO, ERROR
try:
    from osgeo import ogr
except ImportErrror:
    import ogr

SHP='.shp'
SQL_SELECT_RIVER_ID="SELECT id FROM rivers WHERE name = %s"

def findShapefiles(path):
    shapes = []

    for root, dirs, files in os.walk(path):
        if len(files) == 0:
            continue

        DEBUG("Processing directory '%s' with %i files " % (root, len(files)))

        for f in files:
            idx = f.find(SHP)
            if (idx+len(SHP)) == len(f):
                shapes.append((f.replace(SHP, ''), root + "/" + f))

    return shapes

def getRiverId(dbconn, name):
    """
    Returns the id of the river "name"
    Dbconn must be a python database connection api compliant object
    """
    cur = dbconn.cursor()
    cur.execute(SQL_SELECT_RIVER_ID, (name,))
    row = cur.fetchone()
    if row:
        return row[0]
    else:
        return 0

def getUTF8(string):
    """
    Tries to convert the string to a UTF-8 encoding by first checking if it
    is UTF-8 and then trying cp1252
    """
    try:
        return unicode.encode(unicode(string, "UTF-8"), "UTF-8")
    except UnicodeDecodeError:
        # Probably European Windows names so lets try again
        return unicode.encode(unicode(string, "cp1252"), "UTF-8")

def getUTF8Path(path):
    """
    Tries to convert path to utf-8 by first checking the filesystemencoding
    and trying the default windows encoding afterwards.
    Returns a valid UTF-8 encoded unicode object or throws a UnicodeDecodeError
    """
    try:
        return unicode.encode(unicode(path, sys.getfilesystemencoding()), "UTF-8")
    except UnicodeDecodeError:
        # Probably European Windows names so lets try again
        return unicode.encode(unicode(path, "cp1252"), "UTF-8")
